@@ -1921,7 +1921,7 @@ gconf_value_decode (const gchar* encoded)
         const gchar* end = NULL;
         gchar* unquoted;
         
-        gconf_value_set_schema(val, sc);
+        gconf_value_set_schema_nocopy(val, sc);
 
         gconf_schema_set_type(sc, byte_type(*s));
         ++s;
@@ -1932,6 +1932,11 @@ gconf_value_decode (const gchar* encoded)
         gconf_schema_set_cdr_type(sc, byte_type(*s));
         ++s;
 
+        if (*s != ',')
+          g_warning("no comma after types in schema");
+
+	++s;
+
         /* locale */
         unquoted = gconf_unquote_string(s, &end, NULL);
 
@@ -1958,7 +1963,6 @@ gconf_value_decode (const gchar* encoded)
         ++end;
         s = end;
 
-
         /* long */
         unquoted = gconf_unquote_string(s, &end, NULL);
 
@@ -1972,7 +1976,6 @@ gconf_value_decode (const gchar* encoded)
         ++end;
         s = end;
         
-        
         /* default value */
         unquoted = gconf_unquote_string(s, &end, NULL);
 
